@@ -46,7 +46,10 @@ def module_contains_display(expression):
     contains_func_attribute = hasattr(expression.value, "func")
     contains_attrname = hasattr(expression.value.func, "attrname")
     contains_display_attr = expression.value.func.attrname == "display"
-    contains_display_func = expression.value.func.name == "display"
+    for arg in expression.value.args:
+        if isinstance(arg, astroid.nodes.Call):
+            if arg.func.attrname == "display":
+                contains_display_func = True
     return (contains_func_attribute and contains_attrname and contains_display_attr) or (contains_func_attribute and contains_display_func)
         
 
